Struct Portsc1
Source #[repr(transparent)]
pub struct Portsc1(pub u32);
Connect Status Change Flag
Connect Status Change Flag
Port Enable and Disable Change Flag
Port Enable and Disable Change Flag
Wake on Connect Enable (WKCNNT_E)
Wake on Connect Enable (WKCNNT_E)
Wake on Disconnect Enable (WKDSCNNT_E)
Wake on Disconnect Enable (WKDSCNNT_E)
Wake on Overcurrent Enable (WKOC)
Wake on Overcurrent Enable (WKOC)
PHY Low-Power Suspend - Clock Disable (PLPSCD)
PHY Low-Power Suspend - Clock Disable (PLPSCD)
Port Force Full Speed Connect
Port Force Full Speed Connect
Parallel Transceiver Select 2
Parallel Transceiver Select 2
Parallel Transceiver Width
Parallel Transceiver Width
Serial Transceiver Select
Serial Transceiver Select
Parallel Transceiver Select 1
Parallel Transceiver Select 1
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.